# Quick Start

Easily use OpenZeppelin dependencies in your Ape projects.

## Dependencies

- [python3](https://www.python.org/downloads) version 3.8 up to 3.11.

## Installation

### via `pip`

You can install the latest release via [`pip`](https://pypi.org/project/pip/):

```bash
pip install ape-openzeppelin
```

### via `setuptools`

You can clone the repository and use [`setuptools`](https://github.com/pypa/setuptools) for the most up-to-date version:

```bash
git clone https://github.com/antaozoey/ape-openzeppelin.git
cd ape-openzeppelin
python3 setup.py install
```

## Quick Usage

Easily use OpenZeppelin in your Ape project by including a dependency like this:

```yaml
dependencies:
  - openzeppelin: 4.6.0
```

You can also change the name of the dependency if needbe.
You would need to do this if using multiple versions in the same project:

```yaml
dependencies:
  - openzeppelin: 3.6.0
    name: openzeppelin_360
  - openzeppelin: 4.6.0
    name: openzeppelin_460
```

## Development

This project is in development and should be considered a beta.
Things might not be in their final state and breaking changes may occur.
Comments, questions, criticisms and pull requests are welcomed.
